#!/usr/bin/env python
# -*- coding: utf-8 -*-

# How to use a theme.
# Copyright Gummbum, 4/18/2017. Free software, no warranty express or implied.

import math
import random
import re
import pygame
from pygame.colordict import THECOLORS
import hudlight
import hudthemes

# Basic pygame init.
pygame.init()
pygame.display.set_caption('HUD Light - Demo 4, Use Theme | Esc or Close to quit')
clock = pygame.time.Clock()
screen = pygame.display.set_mode((800, 600))
screen_rect = screen.get_rect()

re_grey = re.compile(r'^(grey|gray)\d+$')  # e.g. grey1, gray25, grey99
the_colors = [c for c in THECOLORS.keys() if not re_grey.match(c)]
fill_name = random.choice(the_colors)
fill_color = pygame.Color(fill_name)

paused = False

# A radar sweep visual.
origin = screen_rect.center
radius = 50
angle = 0
arm_color = pygame.Color('white')

# Using a HUD theme.
hudlight.set_font_template('fonts/%s')
theme_name = 'boogaloo'
theme = hudthemes.HUD_THEMES['boogaloo']
hud = hudlight.HUD(**theme)
hud.add('theme', 'Theme {} (Tab key)', theme_name)
hud.add('fill', 'Fill color {}', fill_name)
hud.add('fps', 'FPS {:0.0f}', 0)
hud.add('radians', 'Radians {:0.1f}', angle)
hud.add('paused', 'Paused {} (Space or P key)', paused)

# Make a queue so we can cycle the themes.
theme_names = list(hudthemes.HUD_THEMES)
theme_names.remove('default')
theme_names.remove('boogaloo')
theme_names.append('boogaloo')

while 1:
    clock.tick(60)
    for e in pygame.event.get():
        if e.type == pygame.KEYDOWN:
            if e.key == pygame.K_ESCAPE:
                quit()
            elif e.key in (pygame.K_SPACE, pygame.K_p):
                paused = not paused
                hud.update_item('paused', paused)
            else:
                theme_name = theme_names.pop(0)
                theme = hudthemes.HUD_THEMES[theme_name]
                hudthemes.set_theme(hud, **theme)
                theme_names.append(theme_name)
                hud.update_item('theme', theme_name)
        elif e.type == pygame.QUIT:
            quit()

    if paused:
        continue

    prev_angle = angle
    angle = (angle + 0.025) % (2 * math.pi)
    x = math.cos(angle) * radius + origin[0]
    y = math.sin(angle) * radius + origin[1]

    hud.update_item('fps', clock.get_fps())
    hud.update_item('radians', angle)

    if prev_angle > angle:
        fill_name = random.choice(the_colors)
        fill_color = pygame.Color(fill_name)
        hud.update_item('fill', fill_name)

    screen.fill(fill_color)
    pygame.draw.line(screen, arm_color, origin, (x, y))
    hud.draw(screen)
    pygame.display.flip()
