#!/usr/bin/env python
# -*- coding: utf-8 -*-

# The simplest demo showing some stuffs.
# Copyright Gummbum, 4/18/2017. Free software, no warranty express or implied.

import math
import time
import pygame
import hudlight


class Radar(object):
    def __init__(self):
        self.origin = screen_rect.center
        self.radius = 50
        self.angle = 0
        self.arm_color = pygame.Color('green')
        self.x = 0
        self.y = 0

    def update(self):
        self.angle = (self.angle + 0.025) % (2 * math.pi)
        self.x = math.cos(self.angle) * self.radius + self.origin[0]
        self.y = math.sin(self.angle) * self.radius + self.origin[1]

    def get_angle(self):
        return self.angle

    def draw(self, surf):
        pygame.draw.line(surf, self.arm_color, self.origin, (self.x, self.y))


# Basic pygame init.
pygame.init()
pygame.display.set_caption('HUD Light - Demo 6, Using Callbacks | Esc or Close to quit')
clock = pygame.time.Clock()
screen = pygame.display.set_mode((600, 400))
screen_rect = screen.get_rect()

radar = Radar()

# A HUD to display all my stuffs.
def _obj():
    # Callback returns an object.
    #
    # The format string will take care of accessing the tm_? attributes. Normally a callback would do the heavy lifting
    # of accessing the deep structure, and just return a tuple or list. But I wanted to show something a little more
    # interesting here.
    return time.localtime()
def _dict():
    # Callback for an item that uses keywords in the format.
    return dict(arg1=1.1111, arg2=2.2222)
def _str():
    return 'bleh'
def _not_str():
    return 'A', 'B', 'C'
def _tuple():
    return [(1, 1, 1, 1)]
def _not_tuple():
    return 1, 1
hud = hudlight.HUD()
hud.add('fps', 'FPS {:0.0f}', 0.0, callback=clock.get_fps)
hud.add('radians', 'Radians {:0.1f}', radar.get_angle(), callback=radar.get_angle)
hud.add('time', 'Time {0.tm_hour:02d}:{0.tm_min:02d}:{0.tm_sec:02d}', time.localtime(), callback=_obj)
hud.add('kwargs', 'Kwargs arg1={arg1:0.2f}, arg2={arg2:0.2f}', arg1=0.0, arg2=0.0, callback=_dict)
hud.add('str', 'str {}', 'blah', callback=_str)
hud.add('not str', 'not str {}, {}, {}', 'a', 'b', 'c', callback=_not_str)
hud.add('tuple', 'tuple {}', (0, 0, 0,), callback=_tuple)
hud.add('not tuple', 'not tuple {}, {}', 0, 0, callback=_not_tuple)

while 1:
    clock.tick(60)
    [quit() for e in pygame.event.get() if e.type in (pygame.KEYDOWN, pygame.QUIT)]

    radar.update()
    hud.update()

    screen.fill((0, 0, 0))
    radar.draw(screen)
    hud.draw(screen)
    pygame.display.flip()
